@@ -9,21 +9,21 @@ test_that("column types are correct", {
   expect_true(all(lapply(boxoffice(dates = as.Date("2017-12-25")),
                          class) == col_types))
   expect_true(all(lapply(boxoffice(dates = as.Date("2017-12-25"),
-                                   site = "numbers"), class) == col_types))
+                                   site = "mojo"), class) == col_types))
 
   expect_true(all(lapply(boxoffice(dates = as.Date("2017-12-25"),
                                    top_n = 10), class) == col_types))
   expect_true(all(lapply(boxoffice(dates = as.Date("2017-12-25"),
-                                   site = "numbers",
+                                   site = "mojo",
                                    top_n = 10), class) == col_types))
 
 
   expect_true(all(lapply(boxoffice(dates = christmas), class) == col_types))
   expect_true(all(lapply(boxoffice(dates = christmas,
-                                   site = "numbers"), class) == col_types))
+                                   site = "mojo"), class) == col_types))
 
   expect_true(all(lapply(boxoffice(dates = christmas,
                                    top_n = 10), class) == col_types))
-  expect_true(all(lapply(boxoffice(dates = christmas, site = "numbers",
+  expect_true(all(lapply(boxoffice(dates = christmas, site = "mojo",
                                    top_n = 10), class) == col_types))
 })
